==> qtjambi-help-6.7.0-sources.jar: io/qt/help/QHelpIndexWidget.java <==
package io.qt.help;

import io.qt.*;


/**
 * <p>List view displaying the QHelpIndexModel</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html">QHelpIndexWidget</a></code></p>
 */
public final class QHelpIndexWidget extends io.qt.widgets.QListView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpIndexWidget.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentActivated">QHelpIndexWidget::<wbr/>documentActivated(QHelpLink,<wbr/>QString)</a></code></p>
     */
    public final @NonNull Signal2<io.qt.help.@NonNull QHelpLink, java.lang.@NonNull String> documentActivated = new Signal2<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentsActivated">QHelpIndexWidget::<wbr/>documentsActivated(QList&lt;QHelpLink&gt;,<wbr/>QString)</a></code></p>
     */
    public final @NonNull Signal2<java.util.@NonNull List<io.qt.help.@NonNull QHelpLink>, java.lang.@NonNull String> documentsActivated = new Signal2<>();

    /**
     * <p>See <code>QHelpIndexWidget::<wbr/>linkActivated(QUrl,<wbr/>QString)</code></p>
     */
    public final @NonNull Signal2<io.qt.core.@NonNull QUrl, java.lang.@NonNull String> linkActivated = new Signal2<>();

    /**
     * <p>See <code>QHelpIndexWidget::<wbr/>linksActivated(QMultiMap&lt;QString,<wbr/>QUrl&gt;,<wbr/>QString)</code></p>
     */
    public final @NonNull Signal2<java.util.@NonNull NavigableMap<java.lang.@NonNull String, ? extends java.util.List<io.qt.core.@NonNull QUrl>>, java.lang.@NonNull String> linksActivated = new Signal2<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#activateCurrentItem">QHelpIndexWidget::<wbr/>activateCurrentItem()</a></code></p>
     */
    public final void activateCurrentItem(){
        activateCurrentItem_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void activateCurrentItem_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#filterIndices">QHelpIndexWidget::<wbr/>filterIndices(QString,<wbr/>QString)</a></code></p>
     */
    public final void filterIndices(java.lang.@NonNull String filter, java.lang.@NonNull String wildcard){
        filterIndices_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), filter, wildcard);
    }
    
    private native void filterIndices_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String filter, java.lang.String wildcard);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QHelpIndexWidget(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #filterIndices(java.lang.String, java.lang.String)}
     *  with <code>wildcard = (String)null</code>.</p>
     */
    public final void filterIndices(java.lang.@NonNull String filter) {
        filterIndices(filter, (String)null);
    }
}

==> qtjambi-help-6.7.1-sources.jar: io/qt/help/QHelpIndexWidget.java <==
package io.qt.help;

import io.qt.*;


/**
 * <p>List view displaying the QHelpIndexModel</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html">QHelpIndexWidget</a></code></p>
 */
public final class QHelpIndexWidget extends io.qt.widgets.QListView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpIndexWidget.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentActivated">QHelpIndexWidget::<wbr/>documentActivated(QHelpLink,<wbr/>QString)</a></code></p>
     */
    public final @NonNull Signal2<io.qt.help.@NonNull QHelpLink, java.lang.@NonNull String> documentActivated = new Signal2<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentsActivated">QHelpIndexWidget::<wbr/>documentsActivated(QList&lt;QHelpLink&gt;,<wbr/>QString)</a></code></p>
     */
    public final @NonNull Signal2<java.util.@NonNull List<io.qt.help.@NonNull QHelpLink>, java.lang.@NonNull String> documentsActivated = new Signal2<>();

    /**
     * <p>See <code>QHelpIndexWidget::<wbr/>linkActivated(QUrl,<wbr/>QString)</code></p>
     */
    public final @NonNull Signal2<io.qt.core.@NonNull QUrl, java.lang.@NonNull String> linkActivated = new Signal2<>();

    /**
     * <p>See <code>QHelpIndexWidget::<wbr/>linksActivated(QMultiMap&lt;QString,<wbr/>QUrl&gt;,<wbr/>QString)</code></p>
     */
    public final @NonNull Signal2<java.util.@NonNull NavigableMap<java.lang.@NonNull String, ? extends java.util.List<io.qt.core.@NonNull QUrl>>, java.lang.@NonNull String> linksActivated = new Signal2<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#activateCurrentItem">QHelpIndexWidget::<wbr/>activateCurrentItem()</a></code></p>
     */
    public final void activateCurrentItem(){
        activateCurrentItem_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void activateCurrentItem_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpindexwidget.html#filterIndices">QHelpIndexWidget::<wbr/>filterIndices(QString,<wbr/>QString)</a></code></p>
     */
    public final void filterIndices(java.lang.@NonNull String filter, java.lang.@NonNull String wildcard){
        filterIndices_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), filter, wildcard);
    }
    
    private native void filterIndices_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String filter, java.lang.String wildcard);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    private QHelpIndexWidget(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #filterIndices(java.lang.String, java.lang.String)}
     *  with <code>wildcard = (String)null</code>.</p>
     */
    public final void filterIndices(java.lang.@NonNull String filter) {
        filterIndices(filter, (String)null);
    }
}
